PAGE_NAMED_ARG = 'page'
BODY_NAMED_ARG = 'body'
FILE_POST_NAME = 'embed'

PROTOCOL = 'https'
DOMAIN = 'a2.wykop.pl'

CLIENT_NAME = 'wykop-sdk-reborn'

ANDROID_APPKEY = 'aNd401dAPp'
ANDROID_MIKROBLOG_PLUS_APPKEY = 'd99b6pFK8f'
